/*******************************************************************************
* File Name: PRSm.c
* Version 2.10
*
* Description:
*  This file provides the source code to the API for the PRSm
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PRSm.h"

uint8 PRSm_initVar = 0u;


/*******************************************************************************
* Function Name: PRSm_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default PRSm configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (PRSm__QUAD == PRSm_CONFIG)
        PRSm_CONTROL_REG = PRSm_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        PRSm_TRIG_CONTROL1_REG  = PRSm_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        PRSm_SetInterruptMode(PRSm_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        PRSm_SetCounterMode(PRSm_COUNT_DOWN);
        PRSm_WritePeriod(PRSm_QUAD_PERIOD_INIT_VALUE);
        PRSm_WriteCounter(PRSm_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (PRSm__QUAD == PRSm_CONFIG) */

    #if (PRSm__TIMER == PRSm_CONFIG)
        PRSm_CONTROL_REG = PRSm_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        PRSm_TRIG_CONTROL1_REG  = PRSm_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        PRSm_SetInterruptMode(PRSm_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        PRSm_WritePeriod(PRSm_TC_PERIOD_VALUE );

        #if (PRSm__COMPARE == PRSm_TC_COMP_CAP_MODE)
            PRSm_WriteCompare(PRSm_TC_COMPARE_VALUE);

            #if (1u == PRSm_TC_COMPARE_SWAP)
                PRSm_SetCompareSwap(1u);
                PRSm_WriteCompareBuf(PRSm_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == PRSm_TC_COMPARE_SWAP) */
        #endif  /* (PRSm__COMPARE == PRSm_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (PRSm_CY_TCPWM_V2 && PRSm_TIMER_UPDOWN_CNT_USED && !PRSm_CY_TCPWM_4000)
            PRSm_WriteCounter(1u);
        #elif(PRSm__COUNT_DOWN == PRSm_TC_COUNTER_MODE)
            PRSm_WriteCounter(PRSm_TC_PERIOD_VALUE);
        #else
            PRSm_WriteCounter(0u);
        #endif /* (PRSm_CY_TCPWM_V2 && PRSm_TIMER_UPDOWN_CNT_USED && !PRSm_CY_TCPWM_4000) */
    #endif  /* (PRSm__TIMER == PRSm_CONFIG) */

    #if (PRSm__PWM_SEL == PRSm_CONFIG)
        PRSm_CONTROL_REG = PRSm_CTRL_PWM_BASE_CONFIG;

        #if (PRSm__PWM_PR == PRSm_PWM_MODE)
            PRSm_CONTROL_REG |= PRSm_CTRL_PWM_RUN_MODE;
            PRSm_WriteCounter(PRSm_PWM_PR_INIT_VALUE);
        #else
            PRSm_CONTROL_REG |= PRSm_CTRL_PWM_ALIGN | PRSm_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (PRSm_CY_TCPWM_V2 && PRSm_PWM_UPDOWN_CNT_USED && !PRSm_CY_TCPWM_4000)
                PRSm_WriteCounter(1u);
            #elif (PRSm__RIGHT == PRSm_PWM_ALIGN)
                PRSm_WriteCounter(PRSm_PWM_PERIOD_VALUE);
            #else 
                PRSm_WriteCounter(0u);
            #endif  /* (PRSm_CY_TCPWM_V2 && PRSm_PWM_UPDOWN_CNT_USED && !PRSm_CY_TCPWM_4000) */
        #endif  /* (PRSm__PWM_PR == PRSm_PWM_MODE) */

        #if (PRSm__PWM_DT == PRSm_PWM_MODE)
            PRSm_CONTROL_REG |= PRSm_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (PRSm__PWM_DT == PRSm_PWM_MODE) */

        #if (PRSm__PWM == PRSm_PWM_MODE)
            PRSm_CONTROL_REG |= PRSm_CTRL_PWM_PRESCALER;
        #endif  /* (PRSm__PWM == PRSm_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        PRSm_TRIG_CONTROL1_REG  = PRSm_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        PRSm_SetInterruptMode(PRSm_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (PRSm__PWM_PR == PRSm_PWM_MODE)
            PRSm_TRIG_CONTROL2_REG =
                    (PRSm_CC_MATCH_NO_CHANGE    |
                    PRSm_OVERLOW_NO_CHANGE      |
                    PRSm_UNDERFLOW_NO_CHANGE);
        #else
            #if (PRSm__LEFT == PRSm_PWM_ALIGN)
                PRSm_TRIG_CONTROL2_REG = PRSm_PWM_MODE_LEFT;
            #endif  /* ( PRSm_PWM_LEFT == PRSm_PWM_ALIGN) */

            #if (PRSm__RIGHT == PRSm_PWM_ALIGN)
                PRSm_TRIG_CONTROL2_REG = PRSm_PWM_MODE_RIGHT;
            #endif  /* ( PRSm_PWM_RIGHT == PRSm_PWM_ALIGN) */

            #if (PRSm__CENTER == PRSm_PWM_ALIGN)
                PRSm_TRIG_CONTROL2_REG = PRSm_PWM_MODE_CENTER;
            #endif  /* ( PRSm_PWM_CENTER == PRSm_PWM_ALIGN) */

            #if (PRSm__ASYMMETRIC == PRSm_PWM_ALIGN)
                PRSm_TRIG_CONTROL2_REG = PRSm_PWM_MODE_ASYM;
            #endif  /* (PRSm__ASYMMETRIC == PRSm_PWM_ALIGN) */
        #endif  /* (PRSm__PWM_PR == PRSm_PWM_MODE) */

        /* Set other values from customizer */
        PRSm_WritePeriod(PRSm_PWM_PERIOD_VALUE );
        PRSm_WriteCompare(PRSm_PWM_COMPARE_VALUE);

        #if (1u == PRSm_PWM_COMPARE_SWAP)
            PRSm_SetCompareSwap(1u);
            PRSm_WriteCompareBuf(PRSm_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == PRSm_PWM_COMPARE_SWAP) */

        #if (1u == PRSm_PWM_PERIOD_SWAP)
            PRSm_SetPeriodSwap(1u);
            PRSm_WritePeriodBuf(PRSm_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == PRSm_PWM_PERIOD_SWAP) */
    #endif  /* (PRSm__PWM_SEL == PRSm_CONFIG) */
    
}


/*******************************************************************************
* Function Name: PRSm_Enable
********************************************************************************
*
* Summary:
*  Enables the PRSm.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    PRSm_BLOCK_CONTROL_REG |= PRSm_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (PRSm__PWM_SEL == PRSm_CONFIG)
        #if (0u == PRSm_PWM_START_SIGNAL_PRESENT)
            PRSm_TriggerCommand(PRSm_MASK, PRSm_CMD_START);
        #endif /* (0u == PRSm_PWM_START_SIGNAL_PRESENT) */
    #endif /* (PRSm__PWM_SEL == PRSm_CONFIG) */

    #if (PRSm__TIMER == PRSm_CONFIG)
        #if (0u == PRSm_TC_START_SIGNAL_PRESENT)
            PRSm_TriggerCommand(PRSm_MASK, PRSm_CMD_START);
        #endif /* (0u == PRSm_TC_START_SIGNAL_PRESENT) */
    #endif /* (PRSm__TIMER == PRSm_CONFIG) */
    
    #if (PRSm__QUAD == PRSm_CONFIG)
        #if (0u != PRSm_QUAD_AUTO_START)
            PRSm_TriggerCommand(PRSm_MASK, PRSm_CMD_RELOAD);
        #endif /* (0u != PRSm_QUAD_AUTO_START) */
    #endif  /* (PRSm__QUAD == PRSm_CONFIG) */
}


/*******************************************************************************
* Function Name: PRSm_Start
********************************************************************************
*
* Summary:
*  Initializes the PRSm with default customizer
*  values when called the first time and enables the PRSm.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PRSm_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time PRSm_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the PRSm_Start() routine.
*
*******************************************************************************/
void PRSm_Start(void)
{
    if (0u == PRSm_initVar)
    {
        PRSm_Init();
        PRSm_initVar = 1u;
    }

    PRSm_Enable();
}


/*******************************************************************************
* Function Name: PRSm_Stop
********************************************************************************
*
* Summary:
*  Disables the PRSm.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_BLOCK_CONTROL_REG &= (uint32)~PRSm_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the PRSm. This function is used when
*  configured as a generic PRSm and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the PRSm to operate in
*   Values:
*   - PRSm_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - PRSm_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - PRSm_MODE_QUAD - Quadrature decoder
*         - PRSm_MODE_PWM - PWM
*         - PRSm_MODE_PWM_DT - PWM with dead time
*         - PRSm_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_MODE_MASK;
    PRSm_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - PRSm_MODE_X1 - Counts on phi 1 rising
*         - PRSm_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - PRSm_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_QUAD_MODE_MASK;
    PRSm_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - PRSm_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - PRSm_PRESCALE_DIVBY2    - Divide by 2
*         - PRSm_PRESCALE_DIVBY4    - Divide by 4
*         - PRSm_PRESCALE_DIVBY8    - Divide by 8
*         - PRSm_PRESCALE_DIVBY16   - Divide by 16
*         - PRSm_PRESCALE_DIVBY32   - Divide by 32
*         - PRSm_PRESCALE_DIVBY64   - Divide by 64
*         - PRSm_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_PRESCALER_MASK;
    PRSm_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PRSm runs
*  continuously or stops when terminal count is reached.  By default the
*  PRSm operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_ONESHOT_MASK;
    PRSm_CONTROL_REG |= ((uint32)((oneShotEnable & PRSm_1BIT_MASK) <<
                                                               PRSm_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetPWMMode(uint32 modeMask)
{
    PRSm_TRIG_CONTROL2_REG = (modeMask & PRSm_6BIT_MASK);
}



/*******************************************************************************
* Function Name: PRSm_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_PWM_SYNC_KILL_MASK;
    PRSm_CONTROL_REG |= ((uint32)((syncKillEnable & PRSm_1BIT_MASK)  <<
                                               PRSm_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_PWM_STOP_KILL_MASK;
    PRSm_CONTROL_REG |= ((uint32)((stopOnKillEnable & PRSm_1BIT_MASK)  <<
                                                         PRSm_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_PRESCALER_MASK;
    PRSm_CONTROL_REG |= ((uint32)((deadTime & PRSm_8BIT_MASK) <<
                                                          PRSm_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - PRSm_INVERT_LINE   - Inverts the line output
*         - PRSm_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_INV_OUT_MASK;
    PRSm_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: PRSm_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_WriteCounter(uint32 count)
{
    PRSm_COUNTER_REG = (count & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 PRSm_ReadCounter(void)
{
    return (PRSm_COUNTER_REG & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - PRSm_COUNT_UP       - Counts up
*     - PRSm_COUNT_DOWN     - Counts down
*     - PRSm_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - PRSm_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_UPDOWN_MASK;
    PRSm_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_WritePeriod(uint32 period)
{
    PRSm_PERIOD_REG = (period & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PRSm_ReadPeriod(void)
{
    return (PRSm_PERIOD_REG & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_RELOAD_CC_MASK;
    PRSm_CONTROL_REG |= (swapEnable & PRSm_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_WritePeriodBuf(uint32 periodBuf)
{
    PRSm_PERIOD_BUF_REG = (periodBuf & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 PRSm_ReadPeriodBuf(void)
{
    return (PRSm_PERIOD_BUF_REG & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_CONTROL_REG &= (uint32)~PRSm_RELOAD_PERIOD_MASK;
    PRSm_CONTROL_REG |= ((uint32)((swapEnable & PRSm_1BIT_MASK) <<
                                                            PRSm_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void PRSm_WriteCompare(uint32 compare)
{
    #if (PRSm_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (PRSm_CY_TCPWM_4000) */

    #if (PRSm_CY_TCPWM_4000)
        currentMode = ((PRSm_CONTROL_REG & PRSm_UPDOWN_MASK) >> PRSm_UPDOWN_SHIFT);

        if (((uint32)PRSm__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)PRSm__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (PRSm_CY_TCPWM_4000) */
    
    PRSm_COMP_CAP_REG = (compare & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 PRSm_ReadCompare(void)
{
    #if (PRSm_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (PRSm_CY_TCPWM_4000) */

    #if (PRSm_CY_TCPWM_4000)
        currentMode = ((PRSm_CONTROL_REG & PRSm_UPDOWN_MASK) >> PRSm_UPDOWN_SHIFT);
        
        regVal = PRSm_COMP_CAP_REG;
        
        if (((uint32)PRSm__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)PRSm__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & PRSm_16BIT_MASK);
    #else
        return (PRSm_COMP_CAP_REG & PRSm_16BIT_MASK);
    #endif /* (PRSm_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: PRSm_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void PRSm_WriteCompareBuf(uint32 compareBuf)
{
    #if (PRSm_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (PRSm_CY_TCPWM_4000) */

    #if (PRSm_CY_TCPWM_4000)
        currentMode = ((PRSm_CONTROL_REG & PRSm_UPDOWN_MASK) >> PRSm_UPDOWN_SHIFT);

        if (((uint32)PRSm__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)PRSm__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (PRSm_CY_TCPWM_4000) */
    
    PRSm_COMP_CAP_BUF_REG = (compareBuf & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 PRSm_ReadCompareBuf(void)
{
    #if (PRSm_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (PRSm_CY_TCPWM_4000) */

    #if (PRSm_CY_TCPWM_4000)
        currentMode = ((PRSm_CONTROL_REG & PRSm_UPDOWN_MASK) >> PRSm_UPDOWN_SHIFT);

        regVal = PRSm_COMP_CAP_BUF_REG;
        
        if (((uint32)PRSm__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)PRSm__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & PRSm_16BIT_MASK);
    #else
        return (PRSm_COMP_CAP_BUF_REG & PRSm_16BIT_MASK);
    #endif /* (PRSm_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: PRSm_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 PRSm_ReadCapture(void)
{
    return (PRSm_COMP_CAP_REG & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 PRSm_ReadCaptureBuf(void)
{
    return (PRSm_COMP_CAP_BUF_REG & PRSm_16BIT_MASK);
}


/*******************************************************************************
* Function Name: PRSm_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PRSm_TRIG_LEVEL     - Level
*     - PRSm_TRIG_RISING    - Rising edge
*     - PRSm_TRIG_FALLING   - Falling edge
*     - PRSm_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_TRIG_CONTROL1_REG &= (uint32)~PRSm_CAPTURE_MASK;
    PRSm_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PRSm_TRIG_LEVEL     - Level
*     - PRSm_TRIG_RISING    - Rising edge
*     - PRSm_TRIG_FALLING   - Falling edge
*     - PRSm_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_TRIG_CONTROL1_REG &= (uint32)~PRSm_RELOAD_MASK;
    PRSm_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PRSm_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PRSm_TRIG_LEVEL     - Level
*     - PRSm_TRIG_RISING    - Rising edge
*     - PRSm_TRIG_FALLING   - Falling edge
*     - PRSm_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_TRIG_CONTROL1_REG &= (uint32)~PRSm_START_MASK;
    PRSm_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PRSm_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PRSm_TRIG_LEVEL     - Level
*     - PRSm_TRIG_RISING    - Rising edge
*     - PRSm_TRIG_FALLING   - Falling edge
*     - PRSm_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_TRIG_CONTROL1_REG &= (uint32)~PRSm_STOP_MASK;
    PRSm_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PRSm_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - PRSm_TRIG_LEVEL     - Level
*     - PRSm_TRIG_RISING    - Rising edge
*     - PRSm_TRIG_FALLING   - Falling edge
*     - PRSm_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_TRIG_CONTROL1_REG &= (uint32)~PRSm_COUNT_MASK;
    PRSm_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << PRSm_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - PRSm_CMD_CAPTURE    - Trigger Capture/Switch command
*     - PRSm_CMD_RELOAD     - Trigger Reload/Index command
*     - PRSm_CMD_STOP       - Trigger Stop/Kill command
*     - PRSm_CMD_START      - Trigger Start/phiB command
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    PRSm_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: PRSm_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the PRSm.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - PRSm_STATUS_DOWN    - Set if counting down
*     - PRSm_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 PRSm_ReadStatus(void)
{
    return ((PRSm_STATUS_REG >> PRSm_RUNNING_STATUS_SHIFT) |
            (PRSm_STATUS_REG & PRSm_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: PRSm_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - PRSm_INTR_MASK_TC       - Terminal count mask
*     - PRSm_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetInterruptMode(uint32 interruptMask)
{
    PRSm_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: PRSm_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - PRSm_INTR_MASK_TC       - Terminal count mask
*     - PRSm_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PRSm_GetInterruptSourceMasked(void)
{
    return (PRSm_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: PRSm_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - PRSm_INTR_MASK_TC       - Terminal count mask
*     - PRSm_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 PRSm_GetInterruptSource(void)
{
    return (PRSm_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: PRSm_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - PRSm_INTR_MASK_TC       - Terminal count mask
*     - PRSm_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_ClearInterrupt(uint32 interruptMask)
{
    PRSm_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: PRSm_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - PRSm_INTR_MASK_TC       - Terminal count mask
*     - PRSm_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SetInterrupt(uint32 interruptMask)
{
    PRSm_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
