/*******************************************************************************
* File Name: PRSm_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PRSm.h"

static PRSm_BACKUP_STRUCT PRSm_backup;


/*******************************************************************************
* Function Name: PRSm_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: PRSm_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_Sleep(void)
{
    if(0u != (PRSm_BLOCK_CONTROL_REG & PRSm_MASK))
    {
        PRSm_backup.enableState = 1u;
    }
    else
    {
        PRSm_backup.enableState = 0u;
    }

    PRSm_Stop();
    PRSm_SaveConfig();
}


/*******************************************************************************
* Function Name: PRSm_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: PRSm_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PRSm_Wakeup(void)
{
    PRSm_RestoreConfig();

    if(0u != PRSm_backup.enableState)
    {
        PRSm_Enable();
    }
}


/* [] END OF FILE */
